@@ -22,7 +22,7 @@ public slots:
     QString getLanguage() const;
     void setOrientation(const QString &orient);
     QStringList getInstalledMediaPlayers() const;
-    bool xTubeInstalled();
+    bool widgetInstalled() const;
     void setMediaPlayer(const QString &player);
     void getMediaPlayerFromDB();
     QStringList getProxyFromDB() const;
