@@ -8,9 +8,13 @@
         <translation type="obsolete">cuteTube-QML - 0.6.1</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.0</source>
-        <translation type="unfinished">cuteTube-QML - 0.7.0</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.0</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.7.1</source>
+        <translation type="unfinished">cuteTube-QML - 0.7.1</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -111,13 +115,13 @@
         <translation type="obsolete">Удалить с устройства</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="17"/>
+        <location filename="../ArchiveListView.qml" line="27"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="20"/>
-        <location filename="../ArchiveListView.qml" line="35"/>
+        <location filename="../ArchiveListView.qml" line="30"/>
+        <location filename="../ArchiveListView.qml" line="47"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -461,7 +465,12 @@
         <translation type="obsolete">Скопировать в буфер</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="75"/>
+        <location filename="../PlaylistVideosView.qml" line="59"/>
+        <source>Video(s) deleted from playlist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../PlaylistVideosView.qml" line="80"/>
         <source>No videos found</source>
         <translation>Видео не найдено</translation>
     </message>
@@ -879,8 +888,12 @@
     </message>
     <message>
         <location filename="../SubscriptionsView.qml" line="45"/>
+        <source>You have unsubscribed to this channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>You have unsubscribed to &apos;</source>
-        <translation>Вы больше не подписаны на &apos;</translation>
+        <translation type="obsolete">Вы больше не подписаны на &apos;</translation>
     </message>
     <message>
         <source>Latest Subscription Videos</source>
@@ -1069,12 +1082,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="115"/>
+        <location filename="../UserVideosView.qml" line="117"/>
         <source>You have subscribed to &apos;</source>
         <translation>Вы подписались на &apos;</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="119"/>
+        <location filename="../UserVideosView.qml" line="121"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Вы больше не подписаны на &apos;</translation>
     </message>
@@ -1103,27 +1116,27 @@
         <translation type="obsolete">Копировать в буфер</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="139"/>
+        <location filename="../UserVideosView.qml" line="141"/>
         <source>No videos found</source>
         <translation>Видео не найдено</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="198"/>
+        <location filename="../UserVideosView.qml" line="200"/>
         <source>Subscribers</source>
         <translation>Подписчики</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="212"/>
+        <location filename="../UserVideosView.qml" line="214"/>
         <source>Videos</source>
         <translation>Видео</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="235"/>
+        <location filename="../UserVideosView.qml" line="237"/>
         <source>Unsubscribe</source>
         <translation>Отписаться</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="235"/>
+        <location filename="../UserVideosView.qml" line="237"/>
         <source>Subscribe</source>
         <translation>Подписаться</translation>
     </message>
@@ -1169,7 +1182,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="443"/>
         <location filename="../VideoInfoView.qml" line="467"/>
-        <location filename="../VideoInfoView.qml" line="572"/>
+        <location filename="../VideoInfoView.qml" line="579"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Вы не вошли в аккаунт YouTube</translation>
     </message>
@@ -1216,17 +1229,22 @@
         <translation>Теги</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="584"/>
+        <location filename="../VideoInfoView.qml" line="524"/>
+        <source>No tags</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoInfoView.qml" line="591"/>
         <source>No comments</source>
         <translation>Нет комментариев</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="584"/>
+        <location filename="../VideoInfoView.qml" line="591"/>
         <source> comments</source>
         <translation> комментариев</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="677"/>
+        <location filename="../VideoInfoView.qml" line="684"/>
         <source>No related videos</source>
         <translation>Нет похожих видео</translation>
     </message>
@@ -1276,7 +1294,12 @@
         <translation type="obsolete">Копировать в буфер</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="72"/>
+        <location filename="../VideoListView.qml" line="70"/>
+        <source>Video(s) deleted from favourites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoListView.qml" line="92"/>
         <source>No videos found</source>
         <translation>Видео не найдены</translation>
     </message>
@@ -1340,8 +1363,7 @@
         <translation>Загрузка завершена</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="387"/>
-        <location filename="../../../youtube.cpp" line="424"/>
+        <location filename="../../../youtube.cpp" line="388"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Ошибка: Невозможно получить видео</translation>
     </message>
@@ -1386,72 +1408,72 @@
         <translation type="obsolete">Конвертирую</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="206"/>
+        <location filename="../main.qml" line="207"/>
         <source>Audio</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="211"/>
+        <location filename="../main.qml" line="212"/>
         <source>Conversion of &apos;</source>
         <translation>Конвертация &apos;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="211"/>
+        <location filename="../main.qml" line="212"/>
         <source>&apos; failed</source>
         <translation>&apos; не выполнена</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>High quality</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>Mobile</source>
         <translation type="unfinished">Мобильное</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>360p</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>480p</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="228"/>
         <source>720p</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Queued</source>
         <translation>В очереди</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Paused</source>
         <translation>Пауза</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Downloading</source>
         <translation type="unfinished">Загружается</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="227"/>
+        <location filename="../main.qml" line="229"/>
         <source>Failed</source>
         <translation type="unfinished">Ошибка</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="395"/>
+        <location filename="../main.qml" line="396"/>
         <source>Most Recent</source>
         <translation>Последние</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="396"/>
+        <location filename="../main.qml" line="397"/>
         <source>Most Viewed</source>
         <translation>Популярные</translation>
     </message>
@@ -1463,32 +1485,32 @@
         <translation type="obsolete">Проигрыватель</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="123"/>
+        <location filename="../scripts/mainscripts.js" line="143"/>
         <source>My Channel</source>
         <translation>Мой Канал</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="138"/>
+        <location filename="../scripts/mainscripts.js" line="158"/>
         <source>Archive</source>
         <translation>Архив</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="177"/>
+        <location filename="../scripts/mainscripts.js" line="197"/>
         <source>My Playlists</source>
         <translation>Мой Плейлисты</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="187"/>
+        <location filename="../scripts/mainscripts.js" line="207"/>
         <source>My Subscriptions</source>
         <translation>Мои Подписки</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="200"/>
+        <location filename="../scripts/mainscripts.js" line="220"/>
         <source>Video Info</source>
         <translation>Информация</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
+        <location filename="../scripts/mainscripts.js" line="230"/>
         <source>Video Playback</source>
         <translation>Качество Видео</translation>
     </message>
@@ -1513,7 +1535,7 @@
         <translation type="obsolete">рейтингу</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="223"/>
+        <location filename="../scripts/mainscripts.js" line="243"/>
         <source>Search </source>
         <translation>Поиск </translation>
     </message>
