@@ -1,14 +1,8 @@
 /* Main view functions */
 
-var xTubeInstalled = false;
-
 function restoreSettings() {
     /* Restore the user's settings from the database */
 
-    if (Controller.xTubeInstalled()) {
-        Qt.include("xtube.js");
-        xTubeInstalled = true;
-    }
     Settings.initialize();
     cuteTubeTheme = Settings.getSetting("theme");
     Controller.setOrientation(Settings.getSetting("screenOrientation"));
@@ -66,12 +60,22 @@ function getSubscriptions() {
     doc.onreadystatechange = function() {
         if (doc.readyState == XMLHttpRequest.DONE) {
             var xml = doc.responseText;
-            if (subscriptionsModel.count == 0) {
-                subscriptionsModel.setXml(xml);
-            }
-            else {
-                subscriptionsModel.appendXml(xml);
-            }
+            subscriptionsModel.setXml(xml);
+        }
+    }
+    doc.open("GET", _SUBSCRIPTIONS_FEED);
+    doc.setRequestHeader("Authorization", "GoogleLogin auth=" + YouTube.accessToken);
+    doc.send();
+}
+
+function appendSubscriptions() {
+    /* Append subscriptions to the model */
+
+    var doc = new XMLHttpRequest();
+    doc.onreadystatechange = function() {
+        if (doc.readyState == XMLHttpRequest.DONE) {
+            var xml = doc.responseText;
+            subscriptionsModel.appendXml(xml);
         }
     }
     doc.open("GET", _SUBSCRIPTIONS_FEED + "&start-index=" + (subscriptionsModel.count + 1).toString());
@@ -87,12 +91,22 @@ function getPlaylists() {
     doc.onreadystatechange = function() {
         if (doc.readyState == XMLHttpRequest.DONE) {
             var xml = doc.responseText;
-            if (playlistModel.count == 0) {
-                playlistModel.setXml(xml);
-            }
-            else {
-                playlistModel.appendXml(xml);
-            }
+            playlistModel.setXml(xml);
+        }
+    }
+    doc.open("GET", _PLAYLISTS_FEED);
+    doc.setRequestHeader("Authorization", "GoogleLogin auth=" + YouTube.accessToken);
+    doc.send();
+}
+
+function appendPlaylists() {
+    /* Append playlists to the model */
+
+    var doc = new XMLHttpRequest();
+    doc.onreadystatechange = function() {
+        if (doc.readyState == XMLHttpRequest.DONE) {
+            var xml = doc.responseText;
+            playlistModel.appendXml(xml);
         }
     }
     doc.open("GET", _PLAYLISTS_FEED + "&start-index=" + (playlistModel.count + 1).toString());
@@ -219,36 +233,16 @@ function loadPlaybackView(videoList) {
     loader.item.playbackStopped.connect(stopPlaying);
 }
 
-function youtubeSearch(query, order) {
+function search(query, order) {
     /* Perform a YouTube search and open video list window */
 
+    var encodedQuery = encodeURIComponent(query);
     var safe = Settings.getSetting("safeSearch");
-    var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=" + safe + "&q="
-                     + encodeURIComponent(query).replace(" ", "+") + "&orderby=" + order);
+    var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=" + safe + "&q=%22"
+                     + encodedQuery + "%22%7C" + encodedQuery.replace(" ", "+") + "&orderby=" + order);
     loadVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
 }
 
-function search(query, order) {
-    /* Check if xTube is installed and parse the search query */
-
-    if (xTubeInstalled) {
-        var youjizz = /^yj:/i;
-        var xhamster = /^xh:/i;
-        if (youjizz.test(query)) {
-            youjizzSearch(query.substr(3), order);
-        }
-        else if (xhamster.test(query)) {
-            xhamsterSearch(query.substr(3), order);
-        }
-        else {
-            youtubeSearch(query, order);
-        }
-    }
-    else {
-        youtubeSearch(query, order);
-    }
-}
-
 function toggleMenu() {
     /* Show/hide the menu of the current view */
 
