@@ -134,7 +134,7 @@ function setDefaultSettings() {
                     [ "safeSearch", "none" ],
                     [ "screenOrientation", "automatic" ],
                     [ "mediaPlayer", "Media Player" ],
-                    [ "searchOrder", "published" ],
+                    [ "searchOrder", "relevance" ],
                     [ "theme", "dark" ],
                     [ "language", "en" ],
                     [ "proxy", ":"],
